@@ -3,7 +3,6 @@
 #' This function reduce matrix provided by the user deleting missing categories, those j where sum(datatable[j,]) = sum(datatable[,j]) = 0.
 #' Also provide a list of the categories deleted and provides the new size of the problem
 #'
-
 #' @param datatable Matrix. Expected to be square matrix with at least 2 rows (columns), non negative values and at least an element different of zero.
 #' @keywords M1 datatable
 #' @export
@@ -38,19 +37,3 @@ GetM1 <- function(datatable) {
   return(res)
 }
 
-#' @return \code{NULL}
-#'
-#' @rdname GetM1
-#' @param x List produced by GetM1
-#' @param ... Other print options
-#' @export
-#' @method print GetM1 
-print.GetM1<- function(x,...){
-  cat("Simplified matrix is:\n")
-  print(x$M1)
-  cat("The problem has ", x$k, " categories.\n")
-  if(!is.null( x$Deleted)){
-	 cat("Category(ies) ", x$Deleted, " had been deleted.\n")
-  }
-}
-
